==> create-fly-1.21.8-6.0.8-1-sources.jar: com/zurrtum/create/api/behaviour/interaction/MovingInteractionBehaviour.java <==
package com.zurrtum.create.api.behaviour.interaction;

import com.zurrtum.create.AllClientHandle;
import com.zurrtum.create.api.registry.SimpleRegistry;
import com.zurrtum.create.content.contraptions.AbstractContraptionEntity;
import com.zurrtum.create.content.contraptions.behaviour.MovementContext;
import net.minecraft.class_1268;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_3499.class_3501;
import org.apache.commons.lang3.tuple.MutablePair;

/**
 * MovingInteractionBehaviors define behavior of blocks on contraptions
 * when interacted with by players or collided with by entities.
 */
public abstract class MovingInteractionBehaviour {
    public static final SimpleRegistry<class_2248, MovingInteractionBehaviour> REGISTRY = SimpleRegistry.create();

    protected void setContraptionActorData(AbstractContraptionEntity contraptionEntity, int index, class_3501 info, MovementContext ctx) {
        contraptionEntity.getContraption().getActors().remove(index);
        contraptionEntity.getContraption().getActors().add(index, MutablePair.of(info, ctx));
        if (contraptionEntity.method_37908().field_9236) {
            AllClientHandle.INSTANCE.invalidateClientContraptionChildren(contraptionEntity.getContraption());
        }
    }

    protected void setContraptionBlockData(AbstractContraptionEntity contraptionEntity, class_2338 pos, class_3501 info) {
        if (contraptionEntity.method_37908().method_8608())
            return;
        contraptionEntity.setBlock(pos, info);
    }

    public boolean handlePlayerInteraction(class_1657 player, class_1268 activeHand, class_2338 localPos, AbstractContraptionEntity contraptionEntity) {
        return true;
    }

    public void handleEntityCollision(class_1297 entity, class_2338 localPos, AbstractContraptionEntity contraptionEntity) {
    }
}

==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/api/behaviour/interaction/MovingInteractionBehaviour.java <==
package com.zurrtum.create.api.behaviour.interaction;

import com.zurrtum.create.AllClientHandle;
import com.zurrtum.create.api.registry.SimpleRegistry;
import com.zurrtum.create.content.contraptions.AbstractContraptionEntity;
import com.zurrtum.create.content.contraptions.behaviour.MovementContext;
import net.minecraft.class_1268;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_3499.class_3501;
import org.apache.commons.lang3.tuple.MutablePair;

/**
 * MovingInteractionBehaviors define behavior of blocks on contraptions
 * when interacted with by players or collided with by entities.
 */
public abstract class MovingInteractionBehaviour {
    public static final SimpleRegistry<class_2248, MovingInteractionBehaviour> REGISTRY = SimpleRegistry.create();

    protected void setContraptionActorData(AbstractContraptionEntity contraptionEntity, int index, class_3501 info, MovementContext ctx) {
        contraptionEntity.getContraption().getActors().remove(index);
        contraptionEntity.getContraption().getActors().add(index, MutablePair.of(info, ctx));
        if (contraptionEntity.method_73183().method_8608()) {
            AllClientHandle.INSTANCE.invalidateClientContraptionChildren(contraptionEntity.getContraption());
        }
    }

    protected void setContraptionBlockData(AbstractContraptionEntity contraptionEntity, class_2338 pos, class_3501 info) {
        if (contraptionEntity.method_73183().method_8608())
            return;
        contraptionEntity.setBlock(pos, info);
    }

    public boolean handlePlayerInteraction(class_1657 player, class_1268 activeHand, class_2338 localPos, AbstractContraptionEntity contraptionEntity) {
        return true;
    }

    public void handleEntityCollision(class_1297 entity, class_2338 localPos, AbstractContraptionEntity contraptionEntity) {
    }
}
